@@ -1,7 +1,7 @@
-# -*- coding: iso-8859-1 -*-
-# pylint: disable-msg=R0921,W0613
+# -*- coding: utf-8 -*-
+# pylint: disable-msg = W0613, W0704
 #
-# Copyright 2004-2005 Andr Malo or his licensors, as applicable
+# Copyright 2004-2006 André Malo or his licensors, as applicable
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,10 +23,9 @@ Base notifier class
 @var CTRL_CHARS: provides a list of control chars (< ascii 32)
 @type CTRL_CHARS: C{str}
 """
-__author__    = "Andr Malo"
+__author__    = "André Malo"
 __docformat__ = "epytext en"
 __all__       = ['BaseNotifier']
-__pylintver__ = "0.6.4"
 
 # global imports
 from svnmailer import util
@@ -355,7 +354,7 @@ class BaseNotifier(object):
                     change.getBasePath(), change.getBaseRevision()
                 )
             except exceptions.LookupError:
-                """ fall back """
+                # fall back
                 pass
 
         if change.wasDeleted():
@@ -366,7 +365,7 @@ class BaseNotifier(object):
                     change.path, change.revision
                 )
             except exceptions.LookupError:
-                """ fall back """
+                # fall back
                 pass
 
         if change.wasAdded() and not change.wasCopied():
