@@ -1,7 +1,7 @@
-# -*- coding: iso-8859-1 -*-
-# pylint: disable-msg=W0232,C0103,W0142,W0201
+# -*- coding: utf-8 -*-
+# pylint: disable-msg = C0103, R0901, W0201
 #
-# Copyright 2004-2005 Andr Malo or his licensors, as applicable
+# Copyright 2004-2006 André Malo or his licensors, as applicable
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,13 +23,12 @@ Access to the subversion respository
 @var _SVN_INVALID_REVNUM: the invalid revision number
 @type _SVN_INVALID_REVNUM: C{int}
 """
-__author__    = "Andr Malo"
+__author__    = "André Malo"
 __docformat__ = "epytext en"
 __all__       = [
     'version', 'Repository', 'Error', 'RepositoryError', 'isUnicodeProperty'
     'VersionedPathDescriptor', 'LockedPathDescriptor',
 ]
-__pylintver__ = "0.6.4"
 
 
 # global imports
